%% LaTeX2e Formatklasse fuer Seminarbeitraege
%%
%% Autor: Roland Bless                              -*-Mode: LaTeX;-*-
%% -------------------------------------------------------------------
%% (falls die Umlaute nicht richtig dargestellt werden:
%%  der benutzte Zeichensatz ist ISO 8859-1!)
%% Hinweis für Literatur zu LaTeX 2e:
%% 1. Leslie Lamport: "Das LaTeX-Handbuch", Addison-Wesley 1995
%% 2. Goosens, Mittelbach, Samarin: "Der LaTeX-Begleiter"
%% Referenz und Grundbefehle sind in 1. zu finden, 2. erklärt
%% Zusatz-Pakete, die einem Dokument ein individuelleres Aussehen verleihen
%% können.
%%
% -----------------------------------------------------------------
% $Id: semdoc.cls,v 1.17 2000/05/23 12:14:05 bless Exp $
% -----------------------------------------------------------------
% $Log: semdoc.cls,v $
% Revision 1.17  2000/05/23 12:14:05  bless
% Neues Makro für Abbildungen \Abbildungf.
%
% Revision 1.16  2000/05/23 11:26:46  bless
% Diverse Kommentare, bessere PDF-Unterstützung.
%
% Revision 2.0  2018/06/28 dsukiennik
% Upgrade auf neue Pakete, modernes Layout mit modernen Paketen,
% Unicode
%
% Revision 2.1  2018/09/26 mtheil
% Vorlage weiter verkleinert
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}[2017/04/15] % Sorry, wir brauchen LaTeX2e!

\ProvidesClass{semdoc}[2018/06/18 Seminarbeitrag]
\LoadClass[
	a4paper,
	11pt,
	parskip=yes
]{scrartcl} % diese Klasse basiert auf ``scrartcl''

\usepackage[margin=2.5cm]{geometry}

\usepackage{titling}
\pretitle{\centering\LARGE\bfseries\sffamily}
\posttitle{\\[0.5em]}
\preauthor{\centering\Large}
\postauthor{\\[1.2em]}
\predate{}
\postdate{}
\date{}

\usepackage{ifluatex}
\ifluatex
\usepackage{polyglossia}
\setdefaultlanguage[babelshorthands=true]{german}
\setotherlanguage{english}
\usepackage[ngerman]{selnolig}

\usepackage{fontspec}
\defaultfontfeatures{Ligatures=Common}
\setmainfont{Latin Modern Roman}
\else
%\RequirePackage{ngerman}[1998/07/08] % (v2.5e) Neue Rechtschreibung
\usepackage[utf8]{inputenc} % Eingabe nach ISO 8859-1 (Latin1)
                              % siehe Emacs: iso-accents-mode
%
% Benutze ``Cork'' FontEncoding, damit jeder Umlaut ein eigenes
% Zeichen bekommt (vorher war er durch Zeichen mit Akzent dargestellt).
% Dadurch ist es möglich, daß Wörter mit Umlauten automatisch
% getrennt werden können.
\usepackage[T1]{fontenc}
\usepackage[english, german]{babel}
\fi

\usepackage[final]{graphicx}  % um Graphiken einzubinden (Standard Graphik-Paket)
% Postscript Fonts
% times, palatino, newcent, bookman, garamond, basker,
% lucid, lucidbrb, lucidbry (Kommerzielle Fonts von Y&Y)
\usepackage{lmodern}	% lmodern font

\usepackage{array}          % fuer aufwändigere Tabellen
\usepackage{booktabs}	    % qualitative Tabellen(striche)
\usepackage{longtable}      % seitenübergreifende Tabellen
\usepackage{tabu}       % moderne, dynamische Tabellen
\newcolumntype{L}{>{\raggedright\arraybackslash}X}
\newcolumntype{R}{>{\raggedleft\arraybackslash}X}

\usepackage{amsmath}    % flexible Formelumgebung etc.
\usepackage{amssymb}    % mathematische Sonderzeichen
\usepackage[autostyle=true]{csquotes}	% Systematische und korrekte Anführungszeichen, die vom Compiler überprüft werden
\usepackage[
	hyperref=true,
	backend=biber,
	style=numeric-comp,
]{biblatex}
%% ---------------- end of usepackages -------------

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% New Commands
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Graphik,
%% 3 Argumente: Datei, Label, Unterschrift
\newcommand{\Abbildung}[3]{%
\begin{figure}[tbh] %
\centerline{\includegraphics*{#1}} %
\caption{#3} %
\label{#2} %
\end{figure} %
}

%% Graphik, Angabe der Position, frei wählbares Argument für includegraphics
%% 5 Argumente: Position, Optionen, Datei, Label, Unterschrift
\newcommand{\Abbildungf}[5]{%
\begin{figure}[#1]%
\begin{center}
\includegraphics*[#2]{#3}%
\caption{#5}%
\label{#4}%
\end{center}
\end{figure}%
}

%%%%%

\usepackage{xcolor}   % für farbige Hyperlinks benötigt
\usepackage[
	raiselinks=true,%
	breaklinks=true,%
	bookmarks=true,%
	unicode=true,%
	pdfborder={0 0 0}
]{hyperref} % erzeuge Hyperlinks z.B. für pdflatex

%% **** END OF CLASS ****
